" Vim syntax file
" Language: Markup language for talk text files
" Maintainer: Stefan Schwarzer <sschwarzer@sschwarzer.net>
" Updated: 2010-10-10

" For version 5.x: Clear all syntax items
" For version 6.x: Quit when a syntax file was already loaded
if version < 600
  syntax clear
elseif exists("b:current_syntax")
  finish
endif

syntax case match

" ----------------------------------------------------------
" titles in the document
syntax match talkTitle      /^=\{3,}\n.*\n=\{3,}$/
syntax match talkSubtitle   /^.\+\n-\{3,}$/

" item list
syntax match talkItemList   /^* /
syntax match talkItemList   /^ \s\+- /

" code
syntax region talkInnerInlineCode start=/`/ms=s+1 end=/`/me=s-1 oneline contained
syntax region talkInlineCode start=/`/ end=/`/ oneline contains=talkInnerInlineCode

syntax region talkInnerCodeRegion start=/^\.$/ms=s+1 end=/^\.\.$/me=s-1 contained
syntax region talkCodeRegion start=/^\.$/ end=/^\.\.$/ contains=talkInnerCodeRegion

" links
syntax match talkLink       /http:\/\/\S\+/

" emphasis
syntax match talkEmphasis   /\*\S\(\n\|[^\*]\)\+\S\*/

" Todo markup for [[...]] regions
" let talk_highlight_paragraph_todo = 1
if exists("talk_highlight_paragraph_todo")
  syntax region talkParagraphTodo  start=/\[\[/ end=/\]\]/
endif

" ----------------------------------------------------------
" character-level markup

" ----------------------------------------------------------
" unlet did_talk_syn_inits
if version >= 508 || !exists("did_talk_syn_inits")
  if version <= 508
    let did_talk_syn_inits = 1  " change to 1 when done
    command -nargs=+ HiLink hi link <args>
  else
    command -nargs=+ HiLink hi def link <args>
  endif

  " define actual markup
  highlight talkCodeLightGray guifg=LightGray
  highlight talkCodeGray      guifg=#9999ff

  HiLink talkCode             Comment
  HiLink talkTitle            Title
  HiLink talkSubtitle         Statement
  HiLink talkItemList         Type
  HiLink talkInnerInlineCode  talkCode
  HiLink talkInlineCode       talkCodeGray
  HiLink talkInnerCodeRegion  talkCode
  HiLink talkCodeRegion       talkCodeLightGray
  HiLink talkLink             talkCode
  HiLink talkEmphasis         ModeMsg
  HiLink talkParagraphTodo    Todo

  delcommand HiLink
endif

syntax sync minlines=200

let b:current_syntax = "talk"

" vim: ts=4
